@@ -1,4 +1,3 @@
-{-# LANGUAGE Haskell2010 #-}
 {-# LANGUAGE RankNTypes, TypeOperators, ViewPatterns #-}
 {-# LANGUAGE TypeFamilies #-}
 {-# LANGUAGE DataKinds, PolyKinds, GADTs #-}
@@ -14,7 +13,8 @@ data HTree n a where
   Leaf :: HTree (S n) a
   Branch :: a -> HTree n (HTree (S n) a) -> HTree (S n) a
 
-data STree (n ::Peano) :: forall a . (a -> Type) -> HTree n a -> Type where
+type STree :: forall (n :: Peano) -> forall a. (a -> Type) -> HTree n a -> Type
+data STree n f s where
   SPoint :: f a -> STree Z f (Point a)
   SLeaf :: STree (S n) f Leaf
   SBranch :: f a -> STree n (STree (S n) f) stru -> STree (S n) f (a `Branch` stru)
@@ -34,6 +34,7 @@ hmap f (Point a) = Point (f a)
 hmap f Leaf = Leaf
 hmap f (a `Branch` tr) = f a `Branch` hmap (hmap f) tr
 
-type family Payload (n :: Peano) (s :: HTree n x) :: x where
+type Payload :: forall x. forall (n :: Peano) -> HTree n x -> x
+type family Payload n s where
   Payload Z (Point a) = a
   Payload (S n) (a `Branch` stru) = a
